<?php
/**
 * The plugin bootstrap file
 *
 *
 * @link              https://sendapp.live/
 * @since             1.0.0
 * @package           Xc_Woo_SendApp
 *
 * @wordpress-plugin
 * Plugin Name:       SendApp SMS/WA Notifications
 * Plugin URI:        https://sendapp.live/en/wordpress-woocommerce-sms-and-whatsapp-notifications/
 * Description:       By using SendApp SMS/WhatsApp Notifications you can start sending custom SMS/WhatsApp messages to your customers right away, informing them of any change in the status of the order they placed. Also, you can receive an SMS/WhatsApp message when the shop gets a new order.
 * Version:           1.0.3
 * Author:            SendApp
 * Author URI:        https://sendapp.live/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wp-woo-notify-sendapp
 * Domain Path:       /languages
 * Requires at least: 4.0
 * Tested up to:      5.7
 * WC requires at least: 3.5.0
 * WC tested up to: 5.3.*
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'XC_WOO_SENDAPP_VERSION', '1.0.3' );


// Define XCWPP_PLUGIN_FILE.
if ( ! defined( 'XC_WOO_TWILIO_FILE' ) ) {
	define( 'XC_WOO_TWILIO_FILE', __FILE__ );
}

if ( ! defined( 'XC_WOO_TWILIO_BASENAME' ) ) {
	define( 'XC_WOO_TWILIO_BASENAME', plugin_basename( XC_WOO_TWILIO_FILE ) );
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wp-woo-notify-activator.php
 */
function activate_xc_woo_sendapp() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wp-woo-notify-activator.php';
	Xc_Woo_Sendapp_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wp-woo-notify-deactivator.php
 */
function deactivate_xc_woo_sendapp() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wp-woo-notify-deactivator.php';
	Xc_Woo_Sendapp_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_xc_woo_sendapp' );
register_deactivation_hook( __FILE__, 'deactivate_xc_woo_sendapp' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-wp-woo-notify.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_xc_woo_sendapp() {

	$plugin = new Xc_Woo_Sendapp();
	$plugin->run();

}


/*
* check Woocommerce Activation
*/
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
if ( is_plugin_active( 'woocommerce/woocommerce.php') ){
	// run the plugin
	run_xc_woo_sendapp();
} else {
	// display notices to admin
	add_action( 'admin_notices', 'xc_woo_sendapp_installed_notice' );
}

function xc_woo_sendapp_installed_notice()
{
	?>
    <div class="error">
      <p><?php _e( 'Woocommerce SMS/WhatsApp Notifications requires the WooCommerce plugin. Please install or activate Woocommerce before!', 'wp-woo-notify'); ?></p>
    </div>
    <?php
}